* Replication Code for Boyd and Bellemare (2022)
* "Why Not Insure Prices? Experimental Evidence from Peru,"
* Journal of Economic Behavior & Organization

clear
drop _all

use "C:\priceinsuranceperu.dta"

gen game_id = game*1000 + id
xtset game_id round

tabulate stdev, generate(stdev)

global controls age sex addcompensation gameorder2-gameorder6 lottery_end risk_aversion round
global control round

* Core Results *

* Game 1: Baseline Test of Sandmo's Hypothesis *
* ATE of Price Risk on Output without Insurance *

* Table 2 (FE with controls and clustering)
xtreg production uncertainround $control if game==1, fe cluster(game_id)
xtreg production uncertainround stdev $control if game==1, fe cluster(game_id)
xtreg production stdev2-stdev5 $control if game==1, fe cluster(game_id)

mean production uncertainround if game==1

* Appendix Table 2a (FE with controls and without clustering) *
xtreg production uncertainround $control if game==1, fe 
xtreg production uncertainround stdev $control if game==1, fe 
xtreg production stdev2-stdev5 $control if game==1, fe 

* Appendix Table 2b (FE without controls but with clustering) *
xtreg production uncertainround if game==1, fe cluster(game_id)
xtreg production uncertainround stdev if game==1, fe cluster(game_id) 
xtreg production stdev2-stdev5 if game==1, fe cluster(game_id)

* Appendix Table 2c (FE without controls and without clustering) *
xtreg production uncertainround if game==1, fe 
xtreg production uncertainround stdev if game==1, fe  
xtreg production stdev2-stdev5 if game==1, fe 


* Game 2: Production with Mandatory Insurance *
* ATE of Price Risk on Output with Insurance *

* Table 3 (FE with controls and clustering) *

xtreg production uncertainround $control if game==2, fe cluster(game_id)
xtreg production uncertainround stdev $control if game==2, fe cluster(game_id)
xtreg production stdev2-stdev5 $control if game==2, fe cluster(game_id)

mean production uncertainround if game==2

* Appendix Table 3a (FE with controls and without clustering) *

xtreg production uncertainround $control if game==2, fe 
xtreg production uncertainround stdev $control if game==2, fe 
xtreg production stdev2-stdev5 $control if game==2, fe

* Appendix Table 3b (FE without controls and with clustering) *

xtreg production uncertainround if game==2, fe cluster(game_id)
xtreg production uncertainround stdev if game==2, fe cluster(game_id)
xtreg production stdev2-stdev5 if game==2, fe cluster(game_id)

* Appendix Table 3c (FE without controls and without clustering) *

xtreg production uncertainround if game==2, fe 
xtreg production uncertainround stdev if game==2, fe 
xtreg production stdev2-stdev5 if game==2, fe 

gen game1_uncertainty = game1*uncertainround
gen game2_uncertainty = game2*uncertainround


* Are the coefficients in games 1 and 2 the same? *
* In other words: Is the ATE of price risk the same without and with compulsory insurance? *

* Table 4 (FE with clustering) *

xtreg production game1_uncertainty game2_uncertainty if game==1 | game==2, fe cluster(id)
test game1_uncertainty = game2_uncertainty

xtreg production game1_uncertainty game2_uncertainty $controls if game==1 | game==2, fe cluster(id)
test game1_uncertainty = game2_uncertainty

* Appendix Table 4 (FE without clustering) *

xtreg production game1_uncertainty game2_uncertainty if game==1 | game==2, fe
test game1_uncertainty = game2_uncertainty

xtreg production game1_uncertainty game2_uncertainty $control if game==1 | game==2, fe 
test game1_uncertainty = game2_uncertainty


* Game 3: Production with Voluntary Insurance *
* Uptake of Insurance *

xtset game_id round

gen discount_50 = (discount==50)
gen discount_100 = (discount==100)

xtreg buy_insurance discount if uncertainround==1 & game==3, fe cluster(game_id)
xtreg buy_insurance discount $control if uncertainround==1 & game==3, fe cluster(game_id)

mean buy_insurance if uncertainround==1 & game==3


* Game 3: Production with Voluntary Insurance *
* ITT of Insurance on Output *
* ITT because Take-Up is Voluntary and Not Controlled For *

gen buy_ins_50 = 1 if (buy_insurance==1 & discount==50) & game==3
replace buy_ins_50 = 0 if (buy_insurance==0 | discount~=50) & game==3

gen buy_ins_100 = 1 if (buy_insurance==1 & discount==100) & game==3
replace buy_ins_100 = 0 if (buy_insurance==0 | discount~=100) & game==3

gen uncertain_50 = 1 if (uncertainround==1 & discount==50) & game==3
replace uncertain_50 = 0 if (uncertainround==0 | discount~=50) & game==3

gen uncertain_100 = 1 if (uncertainround==1 & discount==100) & game==3
replace uncertain_100 = 0 if (uncertainround==0 | discount~=100) & game==3

gen discount50 = (discount==50)
gen discount100 = (discount==100)

gen uncertainround_buy_ins_50 = uncertainround*buy_ins_50
gen uncertainround_buy_ins_100 = uncertainround*buy_ins_100

* Table 5 (FE with controls and with clustering) *

xtreg production uncertainround $control if game==3, fe cluster(game_id)
xtreg production uncertainround $control stdev if game==3, fe cluster(game_id)
xtreg production stdev2-stdev5 $control if game==3, fe cluster(game_id)

* Appendix Table 5a (FE with controls and without clustering) *

xtreg production uncertainround $control if game==3, fe 
xtreg production uncertainround $control stdev if game==3, fe 
xtreg production stdev2-stdev5 $control if game==3, fe 

* Appendix Table 5b (FE without controls and with clustering) *

xtreg production uncertainround if game==3, fe cluster(game_id)
xtreg production uncertainround stdev if game==3, fe cluster(game_id)
xtreg production stdev2-stdev5 if game==3, fe cluster(game_id)

* Appendix Table 5c (FE without controls and without clustering) *

xtreg production uncertainround if game==3, fe 
xtreg production uncertainround stdev if game==3, fe 
xtreg production stdev2-stdev5 if game==3, fe 

mean production uncertainround if game==3


* Table 6 (FE with clustering) *

gen game_3=(game==3)
gen uncertainround_game3 = uncertainround*game_3

xtset id round

replace round = round - 40 if game_3==1

xtreg production uncertainround game_3 uncertainround_game3 $control if (game==1 | game==3), fe cluster(id)
xtreg production uncertainround game_3 uncertainround_game3 if (game==1 | game==3), fe cluster(id)

mean production uncertainround if game==1 | game==3


* Appendix Table 6 (FE without clustering)

xtreg production uncertainround game_3 uncertainround_game3 $control if (game==1 | game==3), fe 
xtreg production uncertainround game_3 uncertainround_game3 if (game==1 | game==3), fe 


* LATE *
* Effect of Insurance on Output for Those Who Buy the Insurance Because of Discount *

* Table 7 (FE with clustering) *

xtivreg production (buy_insurance=discount) if uncertainround==1 & game==3, fe first small vce(cluster id)
xtivreg production $controls (buy_insurance=discount) if uncertainround==1 & game==3, fe first small vce(cluster id)
xtivreg production (buy_insurance=discount50 discount100) if uncertainround==1 & game==3, fe first small vce(cluster id)
xtivreg production $controls (buy_insurance=discount50 discount100) if uncertainround==1 & game==3, fe first small vce(cluster id)

mean production uncertainround if game==3

* Appendix Table 7 (FE without clustering) *
xtivreg production (buy_insurance=discount) if uncertainround==1 & game==3, fe first small
xtivreg production $control (buy_insurance=discount) if uncertainround==1 & game==3, fe first small
xtivreg production (buy_insurance=discount50 discount100) if uncertainround==1 & game==3, fe first small
xtivreg production $control (buy_insurance=discount50 discount100) if uncertainround==1 & game==3, fe first small


* Treatment Heterogeneity *

gen u_mono = uncertainround*papa_monocrop

gen u_juntos = uncertainround*juntos

gen u_crra = uncertainround*risk_aversion

gen u_years_potato = uncertainround*years_potato

gen u_price_best = uncertainround*price_best

gen u_price_worst = uncertainround*price_last

gen u_area_potato = uncertainround*area_potato

gen u_distance = uncertainround*distance

gen u_educ_years = uncertainround*educ_years

gen u_ethnic = uncertainround*ethnic

gen u_num_variety = uncertainround*num_variety

gen u_p_selfcons = uncertainround*p_selfcons

gen u_holdsale = uncertainround*hold_sale

gen u_sale_mktprice = uncertainround*sale_mktprice

global hetero u_*


* Game 1 *

* Table 8 (FE with clustering) *
xtreg production uncertainround $hetero if game==1, fe cluster(game_id)
xtreg production uncertainround $hetero $control if game==1, fe cluster(game_id)


* Appendix Table 8 (FE without clustering) *
xtreg production uncertainround $hetero if game==1, fe  
xtreg production uncertainround $hetero $controls if game==1, fe 


* Game 2 *

* Table 9 (FE with clustering) *
xtreg production uncertainround $hetero if game==2, fe cluster(game_id)
xtreg production uncertainround $hetero $control if game==2, fe cluster(game_id)

* Appendix Table 9 (FE without clustering) *
xtreg production uncertainround $hetero if game==2, fe 
xtreg production uncertainround $hetero $controls if game==2, fe










